@@ -15,7 +15,7 @@ class _CustomScalarNode(ScalarNode):
         if isinstance(node, ScalarNode):
             return _CustomScalarNode(node.value, suffix, style=node.style)
         else:
-            raise NotImplementedError('Node: ' + str(type(node)))
+            raise NotImplementedError("Node: " + str(type(node)))
 
     @classmethod
     def to_yaml(cls, dumper: SafeDumper, node: ScalarNode) -> Text:
